summaryrefslogtreecommitdiffstats
path: root/src/qt_qt_wrapper.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/qt_qt_wrapper.cpp')
-rw-r--r--src/qt_qt_wrapper.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/qt_qt_wrapper.cpp b/src/qt_qt_wrapper.cpp
index ff49696..4ef9672 100644
--- a/src/qt_qt_wrapper.cpp
+++ b/src/qt_qt_wrapper.cpp
@@ -166,7 +166,7 @@ void createTQApp()
{
int argc = 1;
char** argv;
// Supply it with fake data to keep KApplication happy
argv = (char**) malloc(sizeof(char*));
argv[0] = (char*) malloc(sizeof(char) * 19);
strncpy(argv[0], "gtk-qt-application", 19);
@@ -177,7 +177,7 @@ void createTQApp()
"message goes here", 0 /* TODO: Website */, "[email protected]");
TDECmdLineArgs::init(argc, argv, &aboutData);
- KApplication::disableAutoDcopRegistration();
+ TDEApplication::disableAutoDcopRegistration();
TQString cmdLine;
@@ -374,7 +374,7 @@ void createTQApp()
if (!tqApp)
{
- new KApplication(gdk_x11_get_default_xdisplay(), true, 0, 0, true);
+ new TDEApplication(gdk_x11_get_default_xdisplay(), true, 0, 0, true);
tqAppOwner = true;
}
@@ -166,7 +166,7 @@ void createTQApp()
int argc = 1;
char** argv;
- // Supply it with fake data to keep KApplication happy
+ // Supply it with fake data to keep TDEApplication happy
argv = (char**) malloc(sizeof(char*));
argv[0] = (char*) malloc(sizeof(char) * 19);